@@ -21,8 +21,26 @@ setAs(from = "features", to = "features_ngrams", def = function(from){
 #' @exportMethod summary
 #' @docType methods
 #' @rdname features-class
-setMethod("summary", "features", function(object){.statisticalSummary(object)})
-
+setMethod("summary", "features", function(object) {
+  if (object@method %in% c("ll", "chisquare")){
+    critical_value <- c(3.84, 6.63, 7.88, 10.83)
+    propability <- c(0.05, 0.01, 0.005, 0.001)
+    no <- vapply(
+      critical_value,
+      function(x) length(which(object@stat[[object@method]] > x)),
+      FUN.VALUE = 1L
+    )
+    result <- data.frame(
+      "propability" = propability,
+      "critical_value" = critical_value,
+      "N" = no
+      )
+    result <- result[order(result$propability, decreasing = FALSE), ]
+    return(result)
+  } else {
+    return(NULL) 
+  }
+})
 
 #' @exportMethod show
 #' @docType methods
@@ -30,11 +48,7 @@ setMethod("summary", "features", function(object){.statisticalSummary(object)})
 setMethod("show", "features", function(object){
   cat("the statistics table has", nrow(object@stat), "rows\n")
   cat("pos attributest have been added: ")
-  if ("pos" %in% colnames(object@stat)){
-    cat("YES\n")
-  } else {
-    cat("NO\n")
-  }
+  if ("pos" %in% colnames(object@stat)) cat("YES\n") else "NO\n"
 })
 
 
@@ -50,9 +64,6 @@ setMethod("summary", "features_bundle", function(object){
 #' @include partition.R partition_bundle.R ngrams.R
 NULL
 
-setGeneric("features", function(x, y, ...) standardGeneric("features"))
-
-
 #' Get features by comparison.
 #' 
 #' The features of two objects, usually a \code{partition} defining a corpus of 
@@ -104,7 +115,13 @@ setGeneric("features", function(x, y, ...) standardGeneric("features"))
 #' speakers <- enrich(speakers, p_attribute = "word")
 #' speaker_terms <- features(speakers[[1:5]], all, included = TRUE, progress = TRUE)
 #' dtm <- as.DocumentTermMatrix(speaker_terms, col = "chisquare")
-#' @rdname  features
+#' @rdname features
+#' @name features
+setGeneric("features", function(x, y, ...) standardGeneric("features"))
+
+
+
+#' @rdname features
 setMethod("features", "partition", function(
   x, y,
   included = FALSE,
