@@ -102,7 +102,7 @@ setMethod("read", "data.table", function(.Object, col, partition_bundle, highlig
 #' @rdname read-method
 setMethod("read", "hits", function(.Object, def, i = NULL, ...){
   if (is.null(i)){
-    for (i in 1:nrow(.Object@stat)){
+    for (i in 1L:nrow(.Object@stat)){
       sAttrs <- lapply(setNames(def, def), function(x) .Object@stat[[x]][i])
       read(partition(.Object@corpus, def = sAttrs, ...))
       readline(">> ")
@@ -111,9 +111,22 @@ setMethod("read", "hits", function(.Object, def, i = NULL, ...){
 })
 
 #' @rdname read-method
-setMethod("read", "kwic", function(.Object, i, type = NULL){
-  fulltext <- html(.Object, i = i, type = type)
-  if (interactive()) htmltools::html_print(fulltext)
+setMethod("read", "kwic", function(.Object, i = NULL, type = registry_get_properties(corpus(.Object))["type"]){
+  
+  # if registry file does not have 'type' corpus property, a named NA vector arrives
+  if (length(type) > 0L) if (is.na(type)) type <- NULL
+  if (!is.null(type)) type <- unname(type)
+
+  if (is.null(i)){
+    for (i in 1L:length(.Object)){
+      read(.Object, i = i, type = type)
+      user <- readline(prompt = "Hit 'q' to quit or any other key to continue.\n")
+      if (user == "q") return(invisible(NULL))
+    }
+  } else {
+    fulltext <- html(.Object, i = i, type = type)
+    if (interactive()) htmltools::html_print(fulltext)
+  }
 })
 
 #' @rdname read-method
